@@ -7,7 +7,9 @@ import re
 import copy
 import json
 import yaml
+import openapi_spec_validator
 import jsonpath_ng
+from typing import Dict, Union, Literal
 
 
 class Bundler(object):
@@ -59,7 +61,6 @@ class Bundler(object):
         return self._output_filename
 
     def bundle(self):
-        import yaml
         self._output_filename = os.path.join(self._output_dir, 'openapi.yaml')
         self._json_filename = os.path.join(self._output_dir, 'openapi.json')
         self._content = {}
@@ -72,29 +73,16 @@ class Bundler(object):
             self._read_file(self._base_dir, self._api_filename)
         self._resolve_x_include()
         self._resolve_x_pattern('x-field-pattern')
-        self._resolve_x_pattern('x-device-pattern')
         self._resolve_x_constraint()
+        self._remove_x_include()
         self._resolve_strings(self._content)
         with open(self._output_filename, 'w') as fp:
             yaml.dump(self._content, fp, indent=2, allow_unicode=True, line_break='\n', sort_keys=False)
         self._validate_file()
         with open(self._json_filename, 'w') as fp:
             fp.write(json.dumps(self._content, indent=4))   
-        try:
-            process_args = [
-                'redoc-cli', 'bundle', 
-                self._output_filename, 
-                '--output', 
-                os.path.join(self._output_dir, 'openapi.html')
-            ]
-            process = subprocess.Popen(process_args, shell=True)
-            process.wait()
-        except Exception as e:
-            print('Bypassed creation of static documentation [missing redoc-cli]: {}'.format(e))
 
     def _validate_file(self):
-        import yaml
-        import openapi_spec_validator
         print('validating {}...'.format(self._output_filename))
         with open(self._output_filename) as fid:
             yobject = yaml.safe_load(fid)
@@ -102,7 +90,6 @@ class Bundler(object):
         print('validating complete')
 
     def _read_file(self, base_dir, filename):
-        import yaml
         filename = os.path.join(base_dir, filename)
         filename = os.path.abspath(os.path.normpath(filename))
         base_dir = os.path.dirname(filename)
@@ -310,18 +297,34 @@ class Bundler(object):
                     'type': 'integer',
                     'default': 1
                 }
-            self._apply_common_x_field_pattern_properties(counter_schema['properties']['start'], xpattern, format)
-            self._apply_common_x_field_pattern_properties(counter_schema['properties']['step'], xpattern, format)
+            self._apply_common_x_field_pattern_properties(counter_schema['properties']['start'], xpattern, format, property_name='start')
+            self._apply_common_x_field_pattern_properties(counter_schema['properties']['step'], xpattern, format, property_name='step')
             if xconstants is not None:
                 counter_schema['x-constants'] = copy.deepcopy(xconstants)
             self._content['components']['schemas'][counter_pattern_name] = counter_schema
-        self._apply_common_x_field_pattern_properties(schema['properties']['value'], xpattern, format)
-        self._apply_common_x_field_pattern_properties(schema['properties']['values']['items'], xpattern, format)
+        self._apply_common_x_field_pattern_properties(schema['properties']['value'], xpattern, format, property_name='value')
+        self._apply_common_x_field_pattern_properties(schema['properties']['values']['items'], xpattern, format, property_name='values')
         self._content['components']['schemas'][schema_name] = schema
 
-    def _apply_common_x_field_pattern_properties(self, schema, xpattern, format):
+    def _apply_common_x_field_pattern_properties(self, 
+        schema: Dict, 
+        xpattern: Dict, 
+        format: str, 
+        property_name: Union[Literal["start"], Literal["step"], Literal["value"], Literal["values"]]):
+        step_defaults = {
+            'mac': '00:00:00:00:00:01',
+            'ipv4': '0.0.0.1',
+            'ipv6': '::1'
+        }
         if 'default' in xpattern:
             schema['default'] = xpattern['default']
+            if property_name == 'step':
+                if format in step_defaults:
+                    schema['default'] = step_defaults[format]
+                else:
+                    schema['default'] = 1
+            elif property_name == 'values':
+                schema['default'] = [schema['default']]        
         if format is not None:
             schema['format'] = format
         if 'length' in xpattern:
@@ -335,18 +338,26 @@ class Bundler(object):
         """
         include_schemas = []
         for xincludes in self._get_parser('$..x-include').find(self._content):
-            print('resolving %s...' % (str(xincludes.full_path)))
-            include_schemas.append(xincludes.full_path)
             parent_schema_object = jsonpath_ng.Parent().find(xincludes)[0].value
             for xinclude in xincludes.value:
+                print('resolving %s...' % (str(xinclude)))
+                include_schemas.append(xinclude)
                 include_schema_object = self._includes[xinclude]
                 self._merge(copy.deepcopy(include_schema_object), parent_schema_object)
             del parent_schema_object['x-include']
+
+    def _remove_x_include(self):
+        refs = self._get_parser('$.."$ref"').find(self._content)
         for item in set(self._includes):
-            content = self._content
             pieces = item.split('#/')[1].split('/')
-            refs = self._get_parser("$..['#/{}']".format('/'.join(pieces))).find(content)
-            if len(pieces) > 2 and len(refs) == 0:
+            value = '#/{}'.format('/'.join(pieces))
+            match = False
+            for ref in refs:
+                if ref.value == value: 
+                    match = True
+                    break
+            if match is False:
+                content = self._content
                 for piece in pieces[0:-1]:
                     content = content[piece]
                 if pieces[-1] in content:
