@@ -390,7 +390,21 @@ class Generator(object):
                 # in snappicommon.py currently expects it
                 self._write(1, '_TYPES = {} # type: Dict[str, str]')
                 self._write()
-            
+            required, defaults = self._get_required_and_defaults(schema_object)
+
+            if len(defaults) > 0:
+                self._write(1, '_DEFAULTS = {')
+                for name, value in defaults:
+                    if isinstance(value, (bool, int, float)):
+                        self._write(2, "'%s': %s," % (name, value))
+                    else:
+                        self._write(2, "'%s': '%s'," % (name, value))
+                self._write(1, '} # type: Dict[str, str]')
+                self._write()
+            else:
+                self._write(1, '_DEFAULTS= {} # type: Dict[str, str]')
+                self._write()
+
             # write constants
             # search for all simple properties with enum or 
             # x-constant and add them here
@@ -609,6 +623,8 @@ class Generator(object):
                 self._write(2, 'item = %s(%s)' % (class_name, ', '.join(params)))
             self._write(2, 'self._add(item)')
             self._write(2, 'return self')
+            self._write()
+            self._write_append_method(yobject, choice_method, class_name, contained_class_name, return_class_name)
         else:
             self._write(1, '@property')
             self._write(1, 'def %s(self):' % (method_name))
@@ -621,33 +637,31 @@ class Generator(object):
             self._write(2, '"""')
             self._write(2, "return self._get_property('%s', %s, self, '%s')" % (method_name, class_name, method_name))
 
-    def _write_append_method(self, param_string):
-            self._imports.append('from .%s import %s' % (class_name.lower(), class_name))
-            self._write(1, 'def append(self, cls=None%s):' % (param_string))
-            return_class_name = class_name
-            if contained_class_name is not None:
-                return_class_name = '{}Iter'.format(contained_class_name)
-            self._write(2, "# type: (%s) -> %s" % (type_string, return_class_name))
-            self._write(2, '"""Factory method that creates an instance of the %s class' % (class_name))
-            self._write()
-            self._write(2, '%s' % self._get_description(yobject))
-            self._write()
-            self._write(2, 'Returns: %s' % (return_class_name))
-            self._write(2, '"""')
-            if choice_method is True:
-                self._write(2, 'item = %s()' % (contained_class_name))
-                self._write(2, "item.%s" % (method_name))
-                self._write(2, "item.choice = '%s'" % (method_name))
-            else:
-                params = [
-                    'parent=self._parent',
-                    'choice=self._choice'
-                ]
-                for property in properties:
-                    params.append('%s=%s' % (property, property))
-                self._write(2, 'item = %s(%s)' % (class_name, ', '.join(params)))
-            self._write(2, 'self._add(item)')
-            self._write(2, 'return self')
+    def _write_append_method(self, yobject, choice_method, class_name, contained_class_name, return_class_name):
+        param_string, properties, type_string = self._get_property_param_string(yobject)
+        self._imports.append('from .%s import %s' % (contained_class_name.lower(), contained_class_name))
+        self._write(1, 'def append(self%s):' % (param_string))
+        self._write(2, "# type: (%s) -> %s" % (type_string, contained_class_name))
+        self._write(2, '"""Factory method that creates and returns an instance of the %s class' % (contained_class_name))
+        self._write()
+        self._write(2, '%s' % self._get_description(yobject))
+        self._write()
+        self._write(2, 'Returns: %s' % (contained_class_name))
+        self._write(2, '"""')
+        if choice_method is True:
+            self._write(2, 'item = %s()' % (contained_class_name))
+            self._write(2, "item.%s" % (method_name))
+            self._write(2, "item.choice = '%s'" % (method_name))
+        else:
+            params = [
+                'parent=self._parent',
+                'choice=self._choice'
+            ]
+            for property in properties:
+                params.append('%s=%s' % (property, property))
+            self._write(2, 'item = %s(%s)' % (class_name, ', '.join(params)))
+        self._write(2, 'self._add(item)')
+        self._write(2, 'return item')
 
     def _get_property_param_string(self, yobject):
         property_param_string = ''
@@ -664,7 +678,7 @@ class Generator(object):
                     properties.append(name)
                     if 'default' in property:
                         default = property['default']
-                    if 'enum' in property or 'format' in property:
+                    if property['type'] == 'string' or 'enum' in property or 'format' in property:
                         val = "=%s" % default if default == 'None' else "='%s'" % default
                         property_param_string += val
                     else:
@@ -744,6 +758,18 @@ class Generator(object):
                     types.append((name, class_name))
         return types
 
+    def _get_required_and_defaults(self, yobject):
+        required = []
+        defaults = []
+        if 'required' in yobject:
+            required = yobject['required']
+        if 'properties' in yobject:
+            for name in yobject['properties']:
+                yproperty = yobject['properties'][name]
+                if 'default' in yproperty:
+                    defaults.append((name, yproperty['default']))
+        return (tuple(required), defaults)
+
     def _get_default_value(self, property):
         if 'default' in property:
             return property['default']
